@@ -23,6 +23,7 @@
 #include <qcheckbox.h>
 #include <qspinbox.h>
 #include <qsizepolicy.h>
+#include <qgroupbox.h>
 
 // include files for KDE
 #include <kiconloader.h>
@@ -44,7 +45,7 @@ KTouch::KTouch(QWidget* , const char* name):KMainWindow(0, name)
   config=kapp->config();
   dirs = KGlobal::dirs();
 
-	touchLecture = new TouchLecture();
+	touchLecture = new TouchLecture( this );
 
   QVBox * view = new QVBox ( this );
 
@@ -60,13 +61,25 @@ KTouch::KTouch(QWidget* , const char* name):KMainWindow(0, name)
 
   setCentralWidget( view );
 
-	QObject::connect( touchLine,    SIGNAL(isError()), touchStatus, SLOT(gotError()));
-	QObject::connect( touchLine,    SIGNAL(isOk()), touchStatus, SLOT(gotOk()));
-	QObject::connect( touchStatus,  SIGNAL(levelUp()), touchLecture, SLOT(levelUp()));
-	QObject::connect( touchStatus,  SIGNAL(levelDown()), touchLecture, SLOT(levelDown()));
-  QObject::connect( touchStatus,  SIGNAL(stop()), touchLine, SLOT(stop()));
-  QObject::connect( touchStatus,  SIGNAL(start()), touchLine, SLOT(start()));
-	QObject::connect( touchLecture, SIGNAL(levelChanged(int)), touchStatus, SLOT(setLevel(int)));
+
+	QObject::connect( touchLine,    SIGNAL(isError()),
+	                  touchStatus,  SLOT(gotError()));
+	QObject::connect( touchLine,    SIGNAL(isOk()),
+	                  touchStatus,  SLOT(gotOk()));
+	QObject::connect( touchStatus,  SIGNAL(levelUp()),
+	                  touchLecture, SLOT(levelUp()));
+	QObject::connect( touchStatus,  SIGNAL(levelDown()),
+	                  touchLecture, SLOT(levelDown()));
+  QObject::connect( touchStatus,  SIGNAL(stop()),
+                    touchLine,    SLOT(stop()));
+  QObject::connect( touchStatus,  SIGNAL(start()),
+                    touchLine,    SLOT(start()));
+  QObject::connect( touchStatus,  SIGNAL(forceNextLine()),
+                    touchLine,    SLOT(getNextLine()));
+  QObject::connect( touchLecture, SIGNAL(levelMessage(const QString&)),
+                    touchStatus,  SLOT(setLevelMessage(const QString&)));
+	QObject::connect( touchLecture, SIGNAL(levelChanged(int)),
+	                  touchStatus,  SLOT(setLevel(int)));
 	QObject::connect( touchLine,    SIGNAL(nextKey(const QChar&)), touchKeyboard, SLOT(newKey(const QChar&)));
 
 
@@ -74,12 +87,9 @@ KTouch::KTouch(QWidget* , const char* name):KMainWindow(0, name)
 	// call inits to invoke all other construction parts
 	initStatusBar();
 	initActions();
-  cout << dirs->localkdedir() << endl;
-  QString trainingFile=dirs->findResource("data","ktouch/english.ktouch");
-  touchLecture->loadLectureFile(trainingFile);
 
 	readOptions();
-  touchLine->getNextLine();
+	touchLine->getNextLine();
 }
 
 void KTouch::initActions()
@@ -92,6 +102,7 @@ void KTouch::initActions()
 
   new KAction(i18n("Keyboard"),0,this,SLOT(slotOptionKeyboard()), actionCollection(),"optionKeyboard");
   new KAction(i18n("Training"),0,this,SLOT(slotOptionTraining()), actionCollection(),"optionTraining");
+  new KAction(i18n("General"),0,this,SLOT(slotOptionGeneral()), actionCollection(),"optionGeneral");
 
   fileOpen->setStatusText(i18n("Opens an existing document"));
   fileOpenRecent->setStatusText(i18n("Opens a recently used file"));
@@ -101,7 +112,7 @@ void KTouch::initActions()
   viewStatusBar->setStatusText(i18n("Enables/disables the statusbar"));
 
   // use the absolute path to your ktouchui.rc file for testing purpose in createGUI();
-  //createGUI("/home/haavard/project/ktouch/ktouch/ktouchui.rc");
+  //createGUI("/home/haavard/ktouch/ktouch/ktouchui.rc");
   createGUI();
 }
 
@@ -139,6 +150,7 @@ void KTouch::saveOptions()
   config->writeEntry("ToolBarPos", (int) toolBar("mainToolBar")->barPos());
   fileOpenRecent->saveEntries(config,"Recent Files");
 
+
   //** History ****************************************************************
   config->setGroup("History");
   config->writeEntry("Speed",touchStatus->getSpeed());
@@ -146,6 +158,7 @@ void KTouch::saveOptions()
   config->writeEntry("Remember",remember);
   config->writeEntry("SpeedLimitUp",touchStatus->getSpeedLimitUp());
   config->writeEntry("SpeedLimitDown",touchStatus->getSpeedLimitDown());
+  config->writeEntry("Auto Level",touchStatus->autoLevel);
 
   //** Keyboard ***************************************************************
   config->setGroup("Keyboard");
@@ -153,8 +166,15 @@ void KTouch::saveOptions()
   config->writeEntry("Show Animation",touchKeyboard->getShowAnimation());
 
   config->writeEntry("Language",touchKeyboard->getLanguage());
-}
 
+  //** General ****************************************************************
+  config->setGroup("General");
+  config->writeEntry("Beep on error",touchStatus->errorSound);
+  config->writeEntry("Color on error",touchLine->getShowError());
+
+  config->writeEntry("ErrorColor",(QColor)touchLine->getErrorColor());
+  config->writeEntry("Font", (QFont)touchLine->getFont());
+}
 
 void KTouch::readOptions()
 {
@@ -162,7 +182,7 @@ void KTouch::readOptions()
   config->setGroup("General Options");
 
   // bar status settings
-  bool bViewToolbar = config->readBoolEntry("Show Toolbar", true);
+  bool bViewToolbar = config->readBoolEntry("Show Toolbar", false);
   viewToolBar->setChecked(bViewToolbar);
   slotViewToolBar();
 
@@ -178,38 +198,58 @@ void KTouch::readOptions()
   // initialize the recent file list
   fileOpenRecent->loadEntries(config,"Recent Files");
 
-  QSize size=config->readSizeEntry("Geometry");
-  if(!size.isEmpty())
-  {
-    resize(size);
-  }
+  // set the size of KTouch
+  QSize size(550,420);
+  size=config->readSizeEntry("Geometry",&size);
+  resize(size);
 
   //** History ****************************************************************
   config->setGroup("History");
-  remember=config->readBoolEntry("Remember");
+
+  remember=config->readBoolEntry("Remember",false);
   if(remember)
   {
-     touchLecture->setLevel(config->readNumEntry("Level"));
-     touchStatus->setSpeed(config->readNumEntry("Speed"));
+     touchLecture->setLevel(config->readNumEntry("Level",1));
+     touchStatus->setSpeed(config->readNumEntry("Speed",0));
   }
   touchStatus->setSpeedLimit(config->readNumEntry("SpeedLimitUp"),config->readNumEntry("SpeedLimitDown"));
 
+  // move this into touchStatus   setAutoLevel(bool b);
+  touchStatus->autoLevel=config->readBoolEntry("Auto Level",true);
+  touchStatus->pushButtonLevelDown->setDisabled(touchStatus->autoLevel);
+  touchStatus->pushButtonLevelUp->setDisabled(touchStatus->autoLevel);
+
+
   //** Keyboard ***************************************************************
   config->setGroup("Keyboard");
-  touchKeyboard->setShowColor(config->readBoolEntry("Show Color"));
-  touchKeyboard->setShowAnimation(config->readBoolEntry("Show Animation"));
-  QString lang=config->readEntry("Language");
-  if(lang.isEmpty()) lang="en";
-  touchKeyboard->loadKeyboard(config->readEntry("Language"));
-}
 
-bool KTouch::queryClose()
-{
-  return true;
+  touchKeyboard->setShowColor(config->readBoolEntry("Show Color",true));
+  touchKeyboard->setShowAnimation(config->readBoolEntry("Show Animation",true));
+  QString lang=config->readEntry("Language","en");
+  touchKeyboard->loadKeyboard(config->readEntry("Language","en"));
+
+  //** General ***************************************************************
+  config->setGroup("General");
+
+  touchStatus->errorSound=config->readBoolEntry("Beep on error",true);
+  touchLine->setShowError(config->readBoolEntry("Color on error",true));
+
+  QColor color(255,150,150);
+  touchLine->setErrorColor(config->readColorEntry("ErrorColor",&color));
+
+  QFont font("adobe-courier");
+  touchLine->setFont(config->readFontEntry("Font",&font));
+
+  // ** Recent files *******************************************************
+  config->setGroup("Recent Files");
+  //QString trainingFile=dirs->findResource("data","ktouch/"+config->readEntry("Last Training File","english.ktouch"));
+  KURL url=config->readEntry("File1",dirs->findResource("data","ktouch/english.ktouch"));
+  touchLecture->loadLectureFile(url.directory(false,true)+url.fileName());
 }
 
 bool KTouch::queryExit()
 {
+  printf("queryExit");
   saveOptions();
   return true;
 }
@@ -221,9 +261,9 @@ bool KTouch::queryExit()
 void KTouch::slotFileOpen()
 {
   slotStatusMsg(i18n("Opening file..."));
-	
-  KURL url=KFileDialog::getOpenURL(QString::null,
-      i18n("*|All files"), this, i18n("Open File..."));
+  KURL url=KFileDialog::getOpenURL(
+      dirs->findResourceDir("data","ktouch/english.ktouch")+"ktouch/",
+      i18n("*.ktouch|KTouch training files"), this, i18n("Open File..."));
   if(!url.isEmpty())
   {
     touchLecture->loadLectureFile(url.directory(false) + url.fileName());
@@ -244,30 +284,17 @@ void KTouch::slotFileOpenRecent(const KURL& url)
     touchLecture->loadLectureFile(url.directory(false) + url.fileName());
     touchLine->getNextLine();
     setCaption(url.fileName(), false);
+    fileOpenRecent->addURL( url );
   }
   slotStatusMsg(i18n("Ready."));
-
 }
 
 void KTouch::slotFileQuit()
 {
   cout << "exit" << endl;
   slotStatusMsg(i18n("Exiting..."));
-  saveOptions();
-  // close the first window, the list makes the next one the first again.
-  // This ensures that queryClose() is called on each window to ask for closing
-  KMainWindow* w;
-  if(memberList)
-  {
-    for(w=memberList->first(); w!=0; w=memberList->first())
-    {
-      // only close the window if the closeEvent is accepted. If the user presses Cancel on the saveModified() dialog,
-      // the window and the application stay open.
-      if(!w->close())
-	break;
-    }
-  }	
-  slotStatusMsg(i18n("Ready."));
+  //saveOptions();
+  close();
 }
 
 void KTouch::slotViewToolBar()
@@ -316,9 +343,12 @@ void KTouch::slotStatusMsg(const QString &text)
 void KTouch::slotOptionKeyboard()
 {
   OptionKeyboard *optionKeyboard=new OptionKeyboard(this,"keyboardOptionDialog",true);
-  optionKeyboard->grabKeyboard();
   optionKeyboard->showColor->setChecked(touchKeyboard->getShowColor());
   optionKeyboard->showAnimation->setChecked(touchKeyboard->getShowAnimation());
+
+  optionKeyboard->languageBox->setDisabled((touchKeyboard->getLanguage()=="number"));
+  optionKeyboard->showKeypad->setChecked((touchKeyboard->getLanguage()=="number"));
+
   for(int i=0;optionKeyboard->language->count()>i;i++)
   {
     if(optionKeyboard->language->text(i)==touchKeyboard->getLanguage())
@@ -332,27 +362,74 @@ void KTouch::slotOptionKeyboard()
   {
     touchKeyboard->setShowColor(optionKeyboard->showColor->isChecked());
     touchKeyboard->setShowAnimation(optionKeyboard->showAnimation->isChecked());
-    touchKeyboard->loadKeyboard(optionKeyboard->language->currentText());
+    if(optionKeyboard->showKeypad->isChecked())
+    {
+      touchKeyboard->loadKeyboard("number");
+
+      //QString trainingFile=dirs->findResource("data","ktouch/number.ktouch");
+      //touchLecture->loadLectureFile(trainingFile);
+      KURL url(dirs->findResource("data","ktouch/number.ktouch"));
+      openDocumentFile(url);
+      slotFileOpenRecent(url);
+    }
+    else
+    {
+      touchKeyboard->loadKeyboard(optionKeyboard->language->currentText());
+      //QString trainingFile=dirs->findResource("data","ktouch/english.ktouch");
+      //touchLecture->loadLectureFile(trainingFile);
+      KURL url(dirs->findResource("data","ktouch/english.ktouch"));
+      openDocumentFile(url);
+      slotFileOpenRecent(url);
+    }
+
   }
   delete optionKeyboard;
-  touchLine->grabKeyboard ();
+  //touchLine->getNextLine();
 }
 
 void KTouch::slotOptionTraining()
 {
   OptionTraining *optionTraining=new OptionTraining(this,"trainingOptionDialog",true);
   optionTraining->limitUp->setValue(touchStatus->getSpeedLimitUp());
+  optionTraining->limitUp->setEnabled(touchStatus->autoLevel);
   optionTraining->limitDown->setValue(touchStatus->getSpeedLimitDown());
+  optionTraining->limitDown->setEnabled(touchStatus->autoLevel);
   optionTraining->remember->setChecked(remember);
+
+  optionTraining->autoLevel->setChecked(touchStatus->autoLevel);
+
+	
   int result = optionTraining->exec();
   if(result==1)
   {
-     touchStatus->setSpeedLimit(optionTraining->limitUp->value(),optionTraining->limitDown->value());
-     remember=optionTraining->remember->isChecked();
+    touchStatus->setSpeedLimit(optionTraining->limitUp->value(),optionTraining->limitDown->value());
+    remember=optionTraining->remember->isChecked();
+
+    touchStatus->autoLevel=optionTraining->autoLevel->isChecked();
+    touchStatus->pushButtonLevelDown->setDisabled(touchStatus->autoLevel);
+    touchStatus->pushButtonLevelUp->setDisabled(touchStatus->autoLevel);
   }
   delete optionTraining;
 }
 
+void KTouch::slotOptionGeneral()
+{
+  OptionGeneral *optionGeneral=new OptionGeneral(this,"generalOptionDialog",true);
+  optionGeneral->beepOnError->setChecked(touchStatus->errorSound);
+  optionGeneral->colorOnError->setChecked(touchLine->getShowError());
+  optionGeneral->showColor->setPalette(QPalette(touchLine->getErrorColor()));
+  optionGeneral->fontChooser->setFont(touchLine->getFont());
+  int result = optionGeneral->exec();
+  if(result==1)
+  {
+     touchStatus->errorSound=optionGeneral->beepOnError->isChecked();
+     touchLine->setShowError(optionGeneral->colorOnError->isChecked());
+     touchLine->setErrorColor(optionGeneral->showColor->backgroundColor());
+     touchLine->setFont(optionGeneral->fontChooser->font());
+  }
+  delete optionGeneral;
+}
+
 void KTouch::keyPressEvent(QKeyEvent*e)
 {
   touchLine->keyPressed(e->ascii());
