@@ -14,8 +14,8 @@
  *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
-#ifndef KTOUCH2_H
-#define KTOUCH2_H
+#ifndef KTOUCH_H
+#define KTOUCH_H
 
 
 #ifdef HAVE_CONFIG_H
@@ -34,13 +34,12 @@
 #include "touchkeyboard.h"
 #include "optionKeyboard.h"
 #include "optionTraining.h"
+#include "optionGeneral.h"
 
 class KTouch : public KMainWindow
 {
   Q_OBJECT
 
-  //friend class KTouch2View;
-
   public:
     /** construtor of KTouch2App, calls all init functions to create the application.
      */
@@ -72,20 +71,8 @@ class KTouch : public KMainWindow
      * @see initView();
      */
 
-    virtual bool queryClose();
-    /** queryExit is called by KTMainWindow when the last window of the application is going to be closed during the closeEvent().
-     * Against the default implementation that just returns true, this calls saveOptions() to save the settings of the last window's	
-     * properties.
-     * @see KTMainWindow#queryExit
-     * @see KTMainWindow#closeEvent
-     */
-    virtual bool queryExit();
-    /** saves the window properties for each open window during session end to the session config file, including saving the currently
-     * opened file by a temporary filename provided by KApplication.
-     * @see KTMainWindow#saveProperties
-     */
-
-    virtual void keyPressEvent(QKeyEvent*e);
+    bool queryExit();
+    void keyPressEvent(QKeyEvent*e);
 
 
   public slots:
@@ -108,6 +95,7 @@ class KTouch : public KMainWindow
 
     void slotOptionKeyboard();
     void slotOptionTraining();
+    void slotOptionGeneral();
 
   private:
     /** the configuration object of the application */
