@@ -26,4 +26,7 @@ OptionKeyboard::~OptionKeyboard()
 {
 }
 
-
+void OptionKeyboard::keyPressEvent(QKeyEvent *)
+{
+  //just to stop the keyPressEvent to go to the main window.
+}
