@@ -26,3 +26,8 @@ OptionTraining::OptionTraining(QWidget *parent, const char *name, bool modal)
 OptionTraining::~OptionTraining()
 {
 }
+
+void OptionTraining::keyPressEvent(QKeyEvent *)
+{
+  //just to stop the keyPressEvent to go to the main window.
+}
