@@ -17,19 +17,19 @@
 
 #include "slideLine.h"
 
-float SlideLine::offset = 0;
-
 SlideLine::SlideLine(QWidget *parent, const char *name)
           :QWidget( parent, name )
 {
-  pixmap=0;
-  pos=0;
-  cursorX=0;
-  cursorY=0;
+  offset = 0;
+  pixmap = 0;
+  pos    = 0;
+  cursorX= 0;
+  cursorY= 0;
   cursorHight=0;
   cursorCount=0;
   font = QFont("adobe-courier", width()/4);
   needRecreate=true;
+  error=false;
 
   timer = new QTimer(this,"timer");
   connect( timer, SIGNAL(timeout()),SLOT(slide()));
@@ -124,7 +124,15 @@ void SlideLine::paintEvent( QPaintEvent * )
     QPainter painter;
     painter.begin (pixmap, this);
     {
-      painter.fillRect (0,height()/2,pixmapSize,height(),QColor(200,255,255));
+      if(error)
+      {
+        painter.fillRect (0,height()/2,pixmapSize,height(),errorColor);
+      }
+      else
+      {
+        painter.fillRect (0,height()/2,pixmapSize,height(),QColor(200,255,255));
+      }
+
       if (pixmapSize<width())
         painter.fillRect (pixmapSize,height()/2,width(),height(),QColor(255,255,255));
       painter.setFont( font );
@@ -152,7 +160,7 @@ void SlideLine::resizeEvent (QResizeEvent *)
 
 void SlideLine::calculateWidth()
 {
-  font = QFont("adobe-courier", height()/4);
+  font.setPointSize(height()/4);
   QFontMetrics fontMetrics( font );
   pixmapSize=fontMetrics.width(teacherText)+100;
 }
@@ -163,3 +171,14 @@ void SlideLine::calculateCursor()
   cursorX=fontMetrics.width(studentText)+22;
 }
 
+void SlideLine::setFont(QFont f)
+{
+  font=f;
+  needRecreate=true;
+}
+
+QFont SlideLine::getFont()
+{
+  return font;
+}
+
