@@ -24,7 +24,6 @@
 #include <qpixmap.h>
 #include <qtimer.h>
 #include <qfontmetrics.h>
-//#include <fstream.h>
 
 class SlideLine: public QWidget
 {
@@ -35,18 +34,23 @@ public:
 
   void setTeacherText(QString text);
   void setStudentText(QString text);
-  static float offset;
+  float offset;
+  bool error;
+  QColor errorColor;
+
+  void setFont(QFont f);
+  QFont getFont();
 
 protected:
  	void paintEvent  ( QPaintEvent * );
 	void resizeEvent ( QResizeEvent * );
 
+
 private:
   bool needRecreate;
   QString teacherText;
   QString studentText;
   QPixmap *pixmap;
-  QFont font;
   int pixmapSize;
   QTimer *timer;
   int pos;
@@ -57,10 +61,10 @@ private:
   int cursorHight;
   void calculateWidth();
   void calculateCursor();
+  QFont font;
 
 private slots:
   void slide();
-
 };
 
 #endif
