@@ -20,12 +20,12 @@
 #include <qlabel.h>
 #include <qapplication.h>
 #include <qprogressbar.h>
-#include <kaudioplayer.h>
 
 TouchStatus::TouchStatus(QWidget * parent, const char * name)
            : TouchStatusLayout( parent, name )
 {
   errorSound=true;
+  autoLevel=true;
   reset();
 
   speedLimitUp = 100;
@@ -60,9 +60,9 @@ void TouchStatus::reset()
 
 void TouchStatus::calculate()
 {
-  speed=(speed*30+bufferOk*120)/31;
-  wrong=(wrong*30+bufferError)/31;
-  correct=(correct*30+bufferOk)/31;
+  speed=(speed*60+bufferOk*120)/61;
+  wrong=(wrong*60+bufferError)/61;
+  correct=(correct*60+bufferOk)/61;
   bufferError=0;
   bufferOk=0;
 
@@ -77,7 +77,7 @@ void TouchStatus::calculate()
   }
 
   testLevelCount++;
-  if (testLevelCount>20)
+  if (testLevelCount>50 && autoLevel)
   {
     testLevelCount=0;
     if (speed>speedLimitUp)
@@ -98,6 +98,23 @@ void TouchStatus::setLevel(int level)
   LCDLevel->display(level+1);
 }
 
+void TouchStatus::levelForcedUp()
+{
+  if(!autoLevel)
+  {
+    emit levelUp();
+    emit forceNextLine();
+  }
+}
+void TouchStatus::levelForcedDown()
+{
+  if(!autoLevel)
+  {
+    emit levelDown();
+    emit forceNextLine();
+  }
+}
+
 unsigned int TouchStatus::getLevel()
 {
  	return (LCDLevel->intValue()-1);
@@ -163,3 +180,8 @@ int TouchStatus::getSpeedLimitUp(){
 int TouchStatus::getSpeedLimitDown(){
 	return speedLimitDown;
 }
+
+void TouchStatus::setLevelMessage(const QString& s)
+{
+  message->setText(s);
+}
