@@ -38,12 +38,16 @@ public:
   int getSpeedLimitDown();
   /** Returns the limit to go to next level */
   int getSpeedLimitUp();
+  bool errorSound;
+  bool autoLevel;
 
 public slots:
   void gotError();
   void gotOk();
   void reset();
   void setLevel(int);
+  void levelForcedUp();
+  void levelForcedDown();
 	unsigned int getLevel();
 	void setSpeed(int);
 	unsigned int getSpeed();
@@ -52,6 +56,7 @@ public slots:
   /** Stops calculating speed and correctness. */
   void stopKTouch();
   void runningStateChanged(int);
+  void setLevelMessage(const QString&);
 
 private:
   QTimer *timer;
@@ -65,7 +70,7 @@ private:
 
   int testLevelCount;
 
-  bool errorSound;
+
 
 private slots:
   void calculate();
@@ -75,6 +80,7 @@ signals:
 	void levelDown();
   void stop();
   void start();
+  void forceNextLine();
 };
 
 #endif
