@@ -29,7 +29,8 @@
 #include "controlkey.h"
 #include "hiddenkey.h"
 
-class TouchKeyboard : public QWidget
+
+class TouchKeyboard: public QWidget
 {
   Q_OBJECT
 public:
@@ -58,6 +59,9 @@ private:
 	bool showAnimation;
   int trans;
   KStandardDirs *dirs;
+  void setIfMax(int w, int h);
+  int maxWidth;
+  int maxHight;
 };
 
 
