@@ -16,82 +16,83 @@
  ***************************************************************************/
 
 #include "touchlecture.h"
-#include <iostream.h>
-#include <fstream.h>
-#include <stdlib.h>
 
-
-#define BUFLEN 256
-
-TouchLecture::TouchLecture()
+TouchLecture::TouchLecture(QWidget *p)
 {
-	fileName="";
+  parent=p;
+  fileName="";
   level=0;
-	pos=0;
+  pos=1;
 };
 
-TouchLecture::~TouchLecture()
+QString TouchLecture::getName()
 {
-};
-
-const char* TouchLecture::getName()
-{
- 	return fileName;
+  return fileName;
 }
 
 void TouchLecture::loadLectureFile(QString f)
 {
-  fileName=f;
-  unsigned int maxLevel=0;
-  levelVector.clear();
-  ifstream ifs(fileName, ios::in);
-  if (!ifs) {
-    cerr << "Error: unable to open " << fileName << endl;
-    fileName="<none>";
+  QFile file(f);
+  if(file.exists())
+  {
+    if (file.open(IO_ReadOnly) )      // file opened successfully
+    {
+      fileName=f;
+      unsigned int maxLevel=0;
+      levelVector.clear();
+
+      QTextStream t( &file );
+      QString s;
+      levelVector.insert(levelVector.end(),new vector<QString>);
+      while ( !t.eof() ) {             // until end of file...
+
+        s = t.readLine();              // line of text excluding '\n'
+
+        if(s.at(0)!='#') // # means that it's a comment
+        {
+          if(s.isEmpty())
+  	    {
+  	       // we detected a line-space so this might be a new level
+           if(!(levelVector[maxLevel]->empty()))
+           {
+              levelVector.insert(levelVector.end(),new vector<QString>);
+  	          maxLevel++;
+           }
+        }
+        else
+        {
+           // adding the line
+           levelVector[maxLevel]->insert(levelVector[maxLevel]->end(),s);
+  				}
+        }
+      }
+    file.close();
+    if(levelVector[maxLevel]->empty())
+    {
+ 	 	  levelVector.erase(&levelVector[maxLevel]);
+      maxLevel--;
+    }
+	
+    setLevel(level);
+    pos=1;
+    }
+    else
+    {
+      //i18n needed here. What do I need to include?
+      QMessageBox::information( parent, "Error reading training file",
+                                        "There was an error when trying to open: "+f );
+    }
   }
   else
-	{
-		char buffer[BUFLEN];
-
-  	levelVector.insert(levelVector.end(),new vector<const char*>);
-  	while (!ifs.eof()) {
-    	ifs.getline(buffer, sizeof(buffer), '\n');
-    	if (!(ifs.eof() && strlen(buffer) == 0)){
-      	if(!(buffer[0]=='#'))
-				{
-        	if(strlen(buffer) == 0)
-					{
-            if(!(levelVector[maxLevel]->empty()))
-            {
-          		levelVector.insert(levelVector.end(),new vector<const char*>);
-							maxLevel++;
-//              cout << "Level read: " << maxLevel << endl;
-            }
-					}
-					else
-					{
-          	char *fitte=new char[strlen(buffer)+1];
-          	for(unsigned int i=0;i<strlen(buffer);i++)
-						{
-							fitte[i]=buffer[i];
-						}
-            fitte[strlen(buffer)]='\0';
-        		levelVector[maxLevel]->insert(levelVector[maxLevel]->end(),fitte);
-					}
-    		}
-    	}
-    }
-    if(levelVector[maxLevel]->empty())
-	  {
-   	 	levelVector.erase(&levelVector[maxLevel]);
-      maxLevel--;
-		}
-    setLevel(level);
-    pos=0;
+  {
+    //i18n needed here. What do I need to include?
+    QMessageBox::information( parent,"Missing training file",
+                                     "The trainingfile specifide dosn't exists: "+f);
   }
-};
+}
 
-const char * TouchLecture::getNextLine()
+
+QString TouchLecture::getNextLine()
 {
   cout << pos << endl;
   if (levelVector.empty())
@@ -100,11 +101,11 @@ const char * TouchLecture::getNextLine()
 	}
   if(level<(levelVector.size()))
   {
-     vector<const char *> test=*levelVector[level];
+     vector<QString> test=*levelVector[level];
 
      if (pos>=(test.size()-1))
 	   {
-		   pos=0;
+		   pos=1;
 	   }
      return test[pos++];
   }
@@ -117,10 +118,10 @@ void TouchLecture::levelUp()
   if(level<(levelVector.size()-1))
 	{
 		level++;
-    emit levelChanged(level);
 		
 		//is good to start at pos 0 every time you change level?
-	  pos=0;
+	  pos=1;
+	  setLevel(level);
 	}
 };
 
@@ -129,10 +130,10 @@ void TouchLecture::levelDown()
   if(level>0)
 	{
 		level--;
-    emit levelChanged(level);
-		
+
 		//is good to start at pos 0 every time you change level?
-  	pos=0;
+  	pos=1;
+  	setLevel(level);
 	}
 
 };
@@ -143,6 +144,12 @@ void TouchLecture::setLevel(unsigned int l)
 	{
    	level=l;
 		emit levelChanged(level);
+		{
+		  vector<QString> test=*levelVector[level];
+		
+		  emit levelMessage(QString(test[0]));
+		
+		}
   }
   else
   {
