@@ -20,6 +20,10 @@
 
 #include <qobject.h>
 #include <qstring.h>
+#include <qfile.h>
+#include <qtextstream.h>
+#include <qmessagebox.h>
+
 #include <vector>
 
 class TouchLecture : public QObject
@@ -27,26 +31,26 @@ class TouchLecture : public QObject
 Q_OBJECT
 
 public:
-  TouchLecture();
-	~TouchLecture();
-  const char* getNextLine();
+  TouchLecture(QWidget *parent=0);
+  QString getNextLine();
   void loadLectureFile(QString fileName);
-  const char* getName();
+  QString getName();
 
 public slots:
   void levelUp();
   void levelDown();
-	void setLevel(unsigned int level);
+  void setLevel(unsigned int level);
 
 signals:
   void levelChanged(int);
+  void levelMessage(const QString&);
 
 private:
   unsigned int pos;
   unsigned int level;
-	vector<vector<const char *> *> levelVector;
+  vector<vector<QString> *> levelVector;
   QString fileName;
-
+  QWidget *parent;
 };
 
 #endif
