@@ -15,8 +15,8 @@
  *                                                                         *
  ***************************************************************************/
 
-#include "touchline.h"
 #include <qapplication.h>
+#include "touchline.h"
 
 
 TouchLine::TouchLine(QWidget * parent, const char * name, TouchLecture *l)
@@ -64,6 +64,8 @@ void TouchLine::keyPressed(QChar e)
   	  else
       {
         emit isError();
+        if(showError)
+          line->error=true;
         // Backspace
         emit nextKey((char)8);
       }
@@ -79,6 +81,7 @@ void TouchLine::keyPressed(QChar e)
         if (teacherLine.left(pos)==studentLine)
   	    {
           emit isOk();
+          line->error=false;
           emit nextKey(teacherLine[pos]);
         }
   			else
@@ -97,7 +100,7 @@ void TouchLine::keyPressed(QChar e)
       }
   	}
     line->setStudentText(studentLine);
-    SlideLine::offset=pos/(float)teacherLine.length();
+    line->offset=pos/(float)teacherLine.length();
   }
   else QApplication::beep();
 }
@@ -105,7 +108,7 @@ void TouchLine::keyPressed(QChar e)
 void TouchLine::setTeacherLine(const QString& t)
 {
 	teacherLine=t;
-  SlideLine::offset=0;
+  line->offset=0;
   line->setTeacherText(teacherLine);
 
 	studentLine = "";
@@ -123,3 +126,35 @@ void TouchLine::start()
 {
   stopped=false;
 }
+
+bool TouchLine::getShowError()
+{
+  return showError;
+}
+
+void TouchLine::setShowError(bool s)
+{
+  showError=s;
+}
+
+QColor TouchLine::getErrorColor()
+{
+  return line->errorColor;
+}
+
+void TouchLine::setErrorColor(QColor c)
+{
+  line->errorColor=c;
+}
+
+QFont TouchLine::getFont()
+{
+  return line->getFont();
+}
+
+void TouchLine::setFont(QFont f)
+{
+  line->setFont(f);
+}
+
+
