@@ -18,6 +18,8 @@
 #ifndef TOUCHLINE_H
 #define TOUCHLINE_H
 
+#include <qcolor.h>
+
 #include "touchlecture.h"
 #include "touchLineLayout.h"
 #include "slideLine.h"
@@ -25,16 +27,18 @@
 class TouchLine: public TouchLineLayout
 {
   Q_OBJECT
-private:
-  unsigned int pos;
-  QString teacherLine;
-  QString studentLine;
-  TouchLecture *lecture;
-  bool stopped;
-
 public:
   TouchLine(QWidget *parent=0, const char *name=0,TouchLecture *myLecture=0);
 	~TouchLine();
+	
+	bool getShowError();
+	void setShowError(bool s);
+	
+	QColor getErrorColor();
+	void setErrorColor(QColor);
+	
+	QFont getFont();
+	void setFont(QFont);
 
 public slots:
   void setTeacherLine(const QString&);
@@ -51,6 +55,16 @@ signals:
   void startKTouch();
   void endOfLine();
   void teacherLineChanged(const QString&);
+
+private:
+  unsigned int pos;
+  QString teacherLine;
+  QString studentLine;
+  TouchLecture *lecture;
+  bool stopped;
+  bool showError;
+
+
 };
 
 #endif
@@ -58,3 +72,4 @@ signals:
 
 
 
+
